@@ -3,6 +3,9 @@ return (
     # Evnements d'diteurs
     'cursor_set_last' => 'Text::Editor::Easy',
     'motion_last'     => 'Text::Editor::Easy',
+    'shift_motion_last'     => 'Text::Editor::Easy',
+    'alt_motion_last'     => 'Text::Editor::Easy',
+    'ctrl_motion_last'     => 'Text::Editor::Easy',
     'on_top_last'     => 'Text::Editor::Easy',
     'insert_last'     => 'Text::Editor::Easy',
     'change_last'     => 'Text::Editor::Easy',
