@@ -1,7 +1,20 @@
+package Text::Editor::Easy::Graphic;
+
+use warnings;
 use strict;
-use warnings;
+
+=head1 NAME
+
+Text::Editor::Easy::Graphic::Gtk_glue - Link between "Text::Editor::Easy::Abstract" and "Gtk". Does not actually work.
+
+=head1 VERSION
+
+Version 0.1
+
+=cut
+
+our $VERSION = '0.1';
 
-package Graphic;
 use Gtk2 -init;
 
 #use Gnome2::Canvas;
@@ -415,4 +428,14 @@ sub redraw_cursor {
     return 1;
 }
 
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2008 Sebastien Grommier, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+
+=cut
+
 1;
